/*************************************************************************
 *   2014 Microchip Technology Inc.
 *
 *  Project Name:    GestIC Message Decoding Demo V2.0
 *  FileName:        hw_profile.c
 *  Dependencies:
 *  Processor:       PIC18F14K50
 *  Compiler:        XC 8 v1.31
 *  IDE:             MPLAB X v2.15
 *  Hardware:        Hillstar I2C to USB bridge
 *  Company:         Microchip Technology Inc.
 * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *  Description:
 *  Hardware Profiles
 *
 *
 *
 *************************************************************************/
/**************************************************************************
 * MICROCHIP SOFTWARE NOTICE AND DISCLAIMER: You may use this software, and
 * any derivatives created by any person or entity by or on your behalf,
 * exclusively with Microchip's products in accordance with applicable
 * software license terms and conditions, a copy of which is provided for
 * your referencein accompanying documentation. Microchip and its licensors
 * retain all ownership and intellectual property rights in the
 * accompanying software and in all derivatives hereto.
 *
 * This software and any accompanying information is for suggestion only.
 * It does not modify Microchip's standard warranty for its products. You
 * agree that you are solely responsible for testing the software and
 * determining its suitability. Microchip has no obligation to modify,
 * test, certify, or support the software.
 *
 * THIS SOFTWARE IS SUPPLIED BY MICROCHIP "AS IS". NO WARRANTIES, WHETHER
 * EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED
 * WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY, AND FITNESS FOR A
 * PARTICULAR PURPOSE APPLY TO THIS SOFTWARE, ITS INTERACTION WITH
 * MICROCHIP'S PRODUCTS, COMBINATION WITH ANY OTHER PRODUCTS, OR USE IN ANY
 * APPLICATION.
 *
 * IN NO EVENT, WILL MICROCHIP BE LIABLE, WHETHER IN CONTRACT, WARRANTY,
 * TORT (INCLUDING NEGLIGENCE OR BREACH OF STATUTORY DUTY), STRICT
 * LIABILITY, INDEMNITY, CONTRIBUTION, OR OTHERWISE, FOR ANY INDIRECT,
 * SPECIAL, PUNITIVE, EXEMPLARY, INCIDENTAL OR CONSEQUENTIAL LOSS, DAMAGE,
 * FOR COST OR EXPENSE OF ANY KIND WHATSOEVER RELATED TO THE SOFTWARE,
 * HOWSOEVER CAUSED, EVEN IF MICROCHIP HAS BEEN ADVISED OF THE POSSIBILITY
 * OR THE DAMAGES ARE FORESEEABLE. TO THE FULLEST EXTENT ALLOWABLE BY LAW,
 * MICROCHIP'S TOTAL LIABILITY ON ALL CLAIMS IN ANY WAY RELATED TO THIS
 * SOFTWARE WILL NOT EXCEED THE AMOUNT OF FEES, IF ANY, THAT YOU HAVE PAID
 * DIRECTLY TO MICROCHIP FOR THIS SOFTWARE.
 *
 * MICROCHIP PROVIDES THIS SOFTWARE CONDITIONALLY UPON YOUR ACCEPTANCE OF
 * THESE TERMS.
 *************************************************************************/


#include "hw_profile.h"
#include "i2c.h"

#if defined (__18F14K50)
    #pragma config CPUDIV = NOCLKDIV    // CPU Clock Divider: NOCLKDIV ==> No CPU System Clock divide, CLKDIV2 ==> CPU System Clock divided by 2
    #pragma config USBDIV = OFF         // USB Clock Divider: ON ==> USB clock comes from the OSC1/OSC2 divided by 2
    #pragma config FOSC   = HS          // Oscillator: HS ==> High Speed
    #pragma config PLLEN  = ON          // Phase Lock Loop: ON ==> Oscillator multiplied by 4
    #pragma config FCMEN  = OFF         // Fail-Safe Clock Monitor disabled
    #pragma config IESO   = OFF         // Oscillator Switchover mode disabled
    #pragma config PWRTEN = OFF         // Power-up Timer disabled
    #pragma config BOREN  = ON         // Brown-out Reset disabled in hardware and software
    #pragma config BORV   = 30          // Brown-out Reset Voltage bits: VBOR set to 3.0 V nominal
    #pragma config WDTEN  = OFF         // Watch dog timer: WDT is controlled by SWDTEN bit of the WDTCON register
    #pragma config WDTPS  = 32768       // Watchdog Timer Postscale Select bits: 1:32768
    #pragma config MCLRE  = OFF         // MCLR Pin Enable bit:RA3 input pin enabled; MCLR disabled
    #pragma config HFOFST = OFF         // HFINTOSC Fast Start-up bit: The system clock is held off until the HFINTOSC is stable.
    #pragma config STVREN = ON          // Stack Full/Underflow Reset Enable bit: Stack full/underflow will cause Reset
    #pragma config LVP    = OFF         // Single-Supply ICSP Enable bit: Single-Supply ICSP disabled
    #pragma config XINST  = OFF         // Extended Instruction Set Enable bit: Instruction set extension and Indexed Addressing mode disabled (Legacy mode)
    #pragma config BBSIZ  = OFF         // Boot Block Size Select bit: 1kW boot block size
    #pragma config CP0    = OFF         // Code Protection bit: Block 0 code-protected
    #pragma config CP1    = OFF
    #pragma config CPB    = OFF         // Boot Block Code Protection bit: protected
    #pragma config WRT0   = OFF         // Table Write Protection bit: Block 1 not write-protected
    #pragma config WRT1   = OFF         //
    #pragma config WRTB   = OFF         // Boot Block Write Protection bit:
    #pragma config WRTC   = OFF         // Configuration Register Write Protection bit:
    #pragma config EBTR0  = OFF         // Table Read Protection bit: Block 0 protected from table reads executed in other blocks
    #pragma config EBTR1  = OFF         //
    #pragma config EBTRB  = OFF         // Boot Block Table Read Protection b

#else
//other processors

#endif

void hwInit(void) {

#if defined (__18F14K50)
//*********Oscillator configuration*********
	//external osc with 12 MHz (PPL with multiplier 4 -> 48MHz)
//*********I/O configuration*********
    ANSEL = 0;  //enable digital input buffers
    ANSELH = 0; //enable digital input buffers
    WPUA = 0x00; //Disable Pull UPs
#else
    //other processors
#endif
    
    //LEDs
    mLED_1 = 0;
    mLED_2 = 0;
    mLED_1_TRIS = 0;
    mLED_2_TRIS = 0;

    //GestIC
    MGC_MCLR = 0;
    MGC_MCLR_TRIS = 0;
    MGC_SCL = 1;
    MGC_SCL_TRIS = 1;
    MGC_SDA_LAT = 1;
    MGC_SDA_TRIS = 1;
    MGC_TS_LAT = 1;
    MGC_TS_TRIS = 1;

//*********Timers configuration*********
#if defined (__18F14K50)
    //Timer 0 - MGC3130 countdown timer (~1.4 kHz)
    T0CONbits.T0CS = 0; //source is internal instruction cycle
    T0CONbits.T0PS = 0b100; //1:32 prescale
    T0CONbits.PSA = 0; //assign prescale
    T0CONbits.T08BIT = 1; //8bit timer
#else
    //other processors
#endif

//*********Component configuration*********
    mgcInit();  //Setup MGC3130
}

//Initialize MGC3130
static void mgcInit(void) {
    //i2c configuration
    MGC_SSPCON1_REG = 0x28; // I2C master mode
    MGC_SSPSTAT_REG = 0x00; // Slew rate control enabled
    MGC_SSPCON2_REG = 0x28;  //Clear Control Bits
    
#if defined (__18F14K50)
    MGC_SSPADD_REG = 0x18;  // BRG divider for 400kHz I2C clock
#else
    //other processors
#endif

    i2c_setbidirectional(); // configure TS line depending on build configuration
    MGC_SSP_BCL_IF = 0;
    MGC_SSP_BCL_IE = 1;     //enable BCL interrupt
    MGC_SSP_IF = 0;
    MGC_SSP_IE = 1;         //enable SSP interrupt

    //wait some time (~2ms) after pulling MGC3130 reset line low; exact timing not crucial
    __delay_ms(2);

    i2cTmr_reset();                 //set counters and enable ints
    i2cTmr_clrInt();
    i2cTmr_Int_enable();

    //release and handle MGC reset line
    MGC_MCLR = 1;
    i2c_handleGestICReset();
}