/*************************************************************************
 *   2014 Microchip Technology Inc.
 *
 *  Project Name:    GestIC Message Decoding Demo V2.0
 *  FileName:        i2c.h
 *  Dependencies:
 *  Processor:       PIC18F14K50
 *  Compiler:        XC 8 v1.31
 *  IDE:             MPLAB X v2.15
 *  Hardware:        Hillstar I2C to USB bridge
 *  Company:         Microchip Technology Inc.
 * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *  Description:
 *  This file contains the header for the i2c handling routine 
 *
 *
 *
 *************************************************************************/
/**************************************************************************
 * MICROCHIP SOFTWARE NOTICE AND DISCLAIMER: You may use this software, and
 * any derivatives created by any person or entity by or on your behalf,
 * exclusively with Microchip's products in accordance with applicable
 * software license terms and conditions, a copy of which is provided for
 * your referencein accompanying documentation. Microchip and its licensors
 * retain all ownership and intellectual property rights in the
 * accompanying software and in all derivatives hereto.
 *
 * This software and any accompanying information is for suggestion only.
 * It does not modify Microchip's standard warranty for its products. You
 * agree that you are solely responsible for testing the software and
 * determining its suitability. Microchip has no obligation to modify,
 * test, certify, or support the software.
 *
 * THIS SOFTWARE IS SUPPLIED BY MICROCHIP "AS IS". NO WARRANTIES, WHETHER
 * EXPRESS, IMPLIED OR STATUTORY, INCLUDING, BUT NOT LIMITED TO, IMPLIED
 * WARRANTIES OF NON-INFRINGEMENT, MERCHANTABILITY, AND FITNESS FOR A
 * PARTICULAR PURPOSE APPLY TO THIS SOFTWARE, ITS INTERACTION WITH
 * MICROCHIP'S PRODUCTS, COMBINATION WITH ANY OTHER PRODUCTS, OR USE IN ANY
 * APPLICATION.
 *
 * IN NO EVENT, WILL MICROCHIP BE LIABLE, WHETHER IN CONTRACT, WARRANTY,
 * TORT (INCLUDING NEGLIGENCE OR BREACH OF STATUTORY DUTY), STRICT
 * LIABILITY, INDEMNITY, CONTRIBUTION, OR OTHERWISE, FOR ANY INDIRECT,
 * SPECIAL, PUNITIVE, EXEMPLARY, INCIDENTAL OR CONSEQUENTIAL LOSS, DAMAGE,
 * FOR COST OR EXPENSE OF ANY KIND WHATSOEVER RELATED TO THE SOFTWARE,
 * HOWSOEVER CAUSED, EVEN IF MICROCHIP HAS BEEN ADVISED OF THE POSSIBILITY
 * OR THE DAMAGES ARE FORESEEABLE. TO THE FULLEST EXTENT ALLOWABLE BY LAW,
 * MICROCHIP'S TOTAL LIABILITY ON ALL CLAIMS IN ANY WAY RELATED TO THIS
 * SOFTWARE WILL NOT EXCEED THE AMOUNT OF FEES, IF ANY, THAT YOU HAVE PAID
 * DIRECTLY TO MICROCHIP FOR THIS SOFTWARE.
 *
 * MICROCHIP PROVIDES THIS SOFTWARE CONDITIONALLY UPON YOUR ACCEPTANCE OF
 * THESE TERMS.
 *************************************************************************/

#ifndef __I2C_H_
#define __I2C_H_

#include <stdint.h>

#define BIDIRECTIONAL       1       //TS in bidirectional mode
#define GESTIC_I2C_ADDR     0x42    // default i2c address of MGC3130
#define MAX_LEN_TO_GESTIC   16 /* maximum length of message to be transferred
                                * to GestIC. Used to setup buffers
                                * Possible values: 4...255
                                */

/* Wait Times - # counts @ ~1.4 KHz*/
#define BERR_WAITTIME       150 //delay for after BCL or MSSP reset
//#define I2C_DEFAULT_WAIT    0   //I2C wait state - set if needed
#define I2C_WAIT_FOR_TS     2   //TS line settling time delay

extern uint8_t countDownReset,
                countDownI2C,
                waitTSline,
                i2cMsgFlag;

inline void i2c_handleGestICReset(void);
void i2c_setbidirectional(void);
void i2c_BCLhandler(void);
void i2c_startWrite(void);
void i2c_TShandler(void);
void i2c_runstatemachine(void);
inline uint8_t i2c_writeBufferInUse(void);
int8_t i2c_sendMsg(uint8_t *msg, uint8_t len);
inline int8_t i2c_gestICSignalsI2C(void);
static inline int8_t checkMasterReset(void);
static inline void i2c_tsSignalStarted(void);
static inline void i2c_irqFinished(void);


#endif // __I2C_H_
